@@ -14,6 +14,8 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+__docformat__ = "google"
+
 """Copying of history from one branch to another.
 
 The basic plan is that every branch knows the history of everything
@@ -24,41 +26,35 @@ branch.
 
 import operator
 
-from ..lazy_import import lazy_import
-lazy_import(globals(), """
-from breezy import (
-    tsort,
-    )
-from breezy.bzr import (
-    versionedfile,
-    vf_search,
-    )
-""")
-from .. import (
-    errors,
-    ui,
-    )
+from .. import errors, ui
 from ..i18n import gettext
 from ..revision import NULL_REVISION
 from ..trace import mutter
 
 
-class RepoFetcher(object):
+class RepoFetcher:
     """Pull revisions and texts from one repository to another.
 
     This should not be used directly, it's essential a object to encapsulate
     the logic in InterRepository.fetch().
     """
 
-    def __init__(self, to_repository, from_repository, last_revision=None,
-                 find_ghosts=True, fetch_spec=None):
+    def __init__(
+        self,
+        to_repository,
+        from_repository,
+        last_revision=None,
+        find_ghosts=True,
+        fetch_spec=None,
+    ):
         """Create a repo fetcher.
 
-        :param last_revision: If set, try to limit to the data this revision
+        Args:
+          last_revision: If set, try to limit to the data this revision
             references.
-        :param fetch_spec: A SearchResult specifying which revisions to fetch.
+          fetch_spec: A SearchResult specifying which revisions to fetch.
             If set, this overrides last_revision.
-        :param find_ghosts: If True search the entire history for ghosts.
+          find_ghosts: If True search the entire history for ghosts.
         """
         # repository.fetch has the responsibility for short-circuiting
         # attempts to copy between a repository and itself.
@@ -70,9 +66,13 @@ class RepoFetcher(object):
         self._fetch_spec = fetch_spec
         self.find_ghosts = find_ghosts
         with self.from_repository.lock_read():
-            mutter("Using fetch logic to copy between %s(%s) and %s(%s)",
-                   str(self.from_repository), str(self.from_repository._format),
-                   str(self.to_repository), str(self.to_repository._format))
+            mutter(
+                "Using fetch logic to copy between %s(%s) and %s(%s)",
+                str(self.from_repository),
+                str(self.from_repository._format),
+                str(self.to_repository),
+                str(self.to_repository._format),
+            )
             self.__fetch()
 
     def __fetch(self):
@@ -93,7 +93,7 @@ class RepoFetcher(object):
             pb.show_pct = pb.show_count = False
             pb.update(gettext("Finding revisions"), 0, 2)
             search_result = self._revids_to_fetch()
-            mutter('fetching: %s', str(search_result))
+            mutter("fetching: %s", str(search_result))
             if search_result.is_empty():
                 return
             pb.update(gettext("Fetching revisions"), 1, 2)
@@ -109,34 +109,37 @@ class RepoFetcher(object):
         # item_keys_introduced_by should have a richer API than it does at the
         # moment, so that it can feed the progress information back to this
         # function?
-        if (self.from_repository._format.rich_root_data and
-                not self.to_repository._format.rich_root_data):
+        if (
+            self.from_repository._format.rich_root_data
+            and not self.to_repository._format.rich_root_data
+        ):
             raise errors.IncompatibleRepositories(
-                self.from_repository, self.to_repository,
-                "different rich-root support")
+                self.from_repository, self.to_repository, "different rich-root support"
+            )
         with ui.ui_factory.nested_progress_bar() as pb:
             pb.update("Get stream source")
-            source = self.from_repository._get_source(
-                self.to_repository._format)
+            source = self.from_repository._get_source(self.to_repository._format)
             stream = source.get_stream(search)
             from_format = self.from_repository._format
             pb.update("Inserting stream")
             resume_tokens, missing_keys = self.sink.insert_stream(
-                stream, from_format, [])
+                stream, from_format, []
+            )
             if missing_keys:
                 pb.update("Missing keys")
                 stream = source.get_stream_for_missing_keys(missing_keys)
                 pb.update("Inserting missing keys")
                 resume_tokens, missing_keys = self.sink.insert_stream(
-                    stream, from_format, resume_tokens)
+                    stream, from_format, resume_tokens
+                )
             if missing_keys:
                 raise AssertionError(
-                    "second push failed to complete a fetch %r." % (
-                        missing_keys,))
+                    "second push failed to complete a fetch {!r}.".format(missing_keys)
+                )
             if resume_tokens:
                 raise AssertionError(
-                    "second push failed to commit the fetch %r." % (
-                        resume_tokens,))
+                    "second push failed to commit the fetch {!r}.".format(resume_tokens)
+                )
             pb.update("Finishing stream")
             self.sink.finished()
 
@@ -144,9 +147,12 @@ class RepoFetcher(object):
         """Determines the exact revisions needed from self.from_repository to
         install self._last_revision in self.to_repository.
 
-        :returns: A SearchResult of some sort.  (Possibly a
-            PendingAncestryResult, EmptySearchResult, etc.)
+        Returns:
+          A SearchResult of some sort.  (Possibly a
+          PendingAncestryResult, EmptySearchResult, etc.)
         """
+        from . import vf_search
+
         if self._fetch_spec is not None:
             # The fetch spec is already a concrete search result.
             return self._fetch_spec
@@ -155,18 +161,20 @@ class RepoFetcher(object):
             # explicit limit of no revisions needed
             return vf_search.EmptySearchResult()
         elif self._last_revision is not None:
-            return vf_search.NotInOtherForRevs(self.to_repository,
-                                               self.from_repository, [
-                                                   self._last_revision],
-                                               find_ghosts=self.find_ghosts).execute()
+            return vf_search.NotInOtherForRevs(
+                self.to_repository,
+                self.from_repository,
+                [self._last_revision],
+                find_ghosts=self.find_ghosts,
+            ).execute()
         else:  # self._last_revision is None:
-            return vf_search.EverythingNotInOther(self.to_repository,
-                                                  self.from_repository,
-                                                  find_ghosts=self.find_ghosts).execute()
+            return vf_search.EverythingNotInOther(
+                self.to_repository, self.from_repository, find_ghosts=self.find_ghosts
+            ).execute()
 
 
-class Inter1and2Helper(object):
-    """Helper for operations that convert data from model 1 and 2
+class Inter1and2Helper:
+    """Helper for operations that convert data from model 1 and 2.
 
     This is for use by fetchers and converters.
     """
@@ -177,7 +185,8 @@ class Inter1and2Helper(object):
     def __init__(self, source):
         """Constructor.
 
-        :param source: The repository data comes from
+        Args:
+          source: The repository data comes from
         """
         self.source = source
 
@@ -189,7 +198,8 @@ class Inter1and2Helper(object):
         Trees are retrieved in batches of 100, and then yielded in the order
         they were requested.
 
-        :param revs: A list of revision ids
+        Args:
+          revs: A list of revision ids
         """
         # In case that revs is not a list.
         revs = list(revs)
@@ -203,8 +213,8 @@ class Inter1and2Helper(object):
     def _find_root_ids(self, revs, parent_map, graph):
         revision_root = {}
         for tree in self.iter_rev_trees(revs):
-            root_id = tree.path2id('')
-            revision_id = tree.get_file_revision(u'')
+            root_id = tree.path2id("")
+            revision_id = tree.get_file_revision("")
             revision_root[revision_id] = root_id
         # Find out which parents we don't already know root ids for
         parents = set(parent_map.values())
@@ -213,21 +223,23 @@ class Inter1and2Helper(object):
         # Limit to revisions present in the versionedfile
         parents = graph.get_parent_map(parents)
         for tree in self.iter_rev_trees(parents):
-            root_id = tree.path2id('')
+            root_id = tree.path2id("")
             revision_root[tree.get_revision_id()] = root_id
         return revision_root
 
     def generate_root_texts(self, revs):
         """Generate VersionedFiles for all root ids.
 
-        :param revs: the revisions to include
+        Args:
+          revs: the revisions to include
         """
+        from ..tsort import topo_sort
+
         graph = self.source.get_graph()
         parent_map = graph.get_parent_map(revs)
-        rev_order = tsort.topo_sort(parent_map)
+        rev_order = topo_sort(parent_map)
         rev_id_to_root_id = self._find_root_ids(revs, parent_map, graph)
-        root_id_order = [(rev_id_to_root_id[rev_id], rev_id) for rev_id in
-                         rev_order]
+        root_id_order = [(rev_id_to_root_id[rev_id], rev_id) for rev_id in rev_order]
         # Guaranteed stable, this groups all the file id operations together
         # retaining topological order within the revisions of a file id.
         # File id splits and joins would invalidate this, but they don't exist
@@ -237,35 +249,41 @@ class Inter1and2Helper(object):
         if len(revs) > self.known_graph_threshold:
             graph = self.source.get_known_graph_ancestry(revs)
         new_roots_stream = _new_root_data_stream(
-            root_id_order, rev_id_to_root_id, parent_map, self.source, graph)
-        return [('texts', new_roots_stream)]
+            root_id_order, rev_id_to_root_id, parent_map, self.source, graph
+        )
+        return [("texts", new_roots_stream)]
 
 
 def _new_root_data_stream(
-        root_keys_to_create, rev_id_to_root_id_map, parent_map, repo, graph=None):
+    root_keys_to_create, rev_id_to_root_id_map, parent_map, repo, graph=None
+):
     """Generate a texts substream of synthesised root entries.
 
     Used in fetches that do rich-root upgrades.
 
-    :param root_keys_to_create: iterable of (root_id, rev_id) pairs describing
+    Args:
+      root_keys_to_create: iterable of (root_id, rev_id) pairs describing
         the root entries to create.
-    :param rev_id_to_root_id_map: dict of known rev_id -> root_id mappings for
+      rev_id_to_root_id_map: dict of known rev_id -> root_id mappings for
         calculating the parents.  If a parent rev_id is not found here then it
         will be recalculated.
-    :param parent_map: a parent map for all the revisions in
+      parent_map: a parent map for all the revisions in
         root_keys_to_create.
-    :param graph: a graph to use instead of repo.get_graph().
+      graph: a graph to use instead of repo.get_graph().
     """
+    from .versionedfile import ChunkedContentFactory
+
     for root_key in root_keys_to_create:
         root_id, rev_id = root_key
         parent_keys = _parent_keys_for_root_version(
-            root_id, rev_id, rev_id_to_root_id_map, parent_map, repo, graph)
-        yield versionedfile.ChunkedContentFactory(
-            root_key, parent_keys, None, [])
+            root_id, rev_id, rev_id_to_root_id_map, parent_map, repo, graph
+        )
+        yield ChunkedContentFactory(root_key, parent_keys, None, [])
 
 
 def _parent_keys_for_root_version(
-        root_id, rev_id, rev_id_to_root_id_map, parent_map, repo, graph=None):
+    root_id, rev_id, rev_id_to_root_id_map, parent_map, repo, graph=None
+):
     """Get the parent keys for a given root id.
 
     A helper function for _new_root_data_stream.
@@ -288,7 +306,7 @@ def _parent_keys_for_root_version(
                 # But set parent_root_id to None since we don't really know
                 parent_root_id = None
             else:
-                parent_root_id = tree.path2id('')
+                parent_root_id = tree.path2id("")
             rev_id_to_root_id_map[parent_id] = None
             # XXX: why not:
             #   rev_id_to_root_id_map[parent_id] = parent_root_id
@@ -311,8 +329,8 @@ def _parent_keys_for_root_version(
             else:
                 try:
                     parent_ids.append(
-                        tree.get_file_revision(
-                            tree.id2path(root_id, recurse='none')))
+                        tree.get_file_revision(tree.id2path(root_id, recurse="none"))
+                    )
                 except errors.NoSuchId:
                     # not in the tree
                     pass
@@ -328,18 +346,18 @@ def _parent_keys_for_root_version(
     return parent_keys
 
 
-class TargetRepoKinds(object):
+class TargetRepoKinds:
     """An enum-like set of constants.
 
     They are the possible values of FetchSpecFactory.target_repo_kinds.
     """
 
-    PREEXISTING = 'preexisting'
-    STACKED = 'stacked'
-    EMPTY = 'empty'
+    PREEXISTING = "preexisting"
+    STACKED = "stacked"
+    EMPTY = "empty"
 
 
-class FetchSpecFactory(object):
+class FetchSpecFactory:
     """A helper for building the best fetch spec for a sprout call.
 
     Factors that go into determining the sort of fetch to perform:
@@ -351,12 +369,13 @@ class FetchSpecFactory(object):
      * target is stacked?  (similar to pre-existing target repo: even if
        the target itself is new don't want to refetch existing revs)
 
-    :ivar source_branch: the source branch if one specified, else None.
-    :ivar source_branch_stop_revision_id: fetch up to this revision of
+    Attributes:
+      source_branch: the source branch if one specified, else None.
+      source_branch_stop_revision_id: fetch up to this revision of
         source_branch, rather than its tip.
-    :ivar source_repo: the source repository if one found, else None.
-    :ivar target_repo: the target repository acquired by sprout.
-    :ivar target_repo_kind: one of the TargetRepoKinds constants.
+      source_repo: the source repository if one found, else None.
+      target_repo: the target repository acquired by sprout.
+      target_repo_kind: one of the TargetRepoKinds constants.
     """
 
     def __init__(self):
@@ -374,13 +393,17 @@ class FetchSpecFactory(object):
 
     def make_fetch_spec(self):
         """Build a SearchResult or PendingAncestryResult or etc."""
+        from . import vf_search
+
         if self.target_repo_kind is None or self.source_repo is None:
             raise AssertionError(
-                'Incomplete FetchSpecFactory: %r' % (self.__dict__,))
+                "Incomplete FetchSpecFactory: {!r}".format(self.__dict__)
+            )
         if len(self._explicit_rev_ids) == 0 and self.source_branch is None:
             if self.limit is not None:
                 raise NotImplementedError(
-                    "limit is only supported with a source branch set")
+                    "limit is only supported with a source branch set"
+                )
             # Caller hasn't specified any revisions or source branch
             if self.target_repo_kind == TargetRepoKinds.EMPTY:
                 return vf_search.EverythingResult(self.source_repo)
@@ -388,7 +411,8 @@ class FetchSpecFactory(object):
                 # We want everything not already in the target (or target's
                 # fallbacks).
                 return vf_search.EverythingNotInOther(
-                    self.target_repo, self.source_repo).execute()
+                    self.target_repo, self.source_repo
+                ).execute()
         heads_to_fetch = set(self._explicit_rev_ids)
         if self.source_branch is not None:
             must_fetch, if_present_fetch = self.source_branch.heads_to_fetch()
@@ -414,11 +438,14 @@ class FetchSpecFactory(object):
             if self.limit is not None:
                 graph = self.source_repo.get_graph()
                 topo_order = list(graph.iter_topo_order(ret.get_keys()))
-                result_set = topo_order[:self.limit]
-                ret = self.source_repo.revision_ids_to_search_result(
-                    result_set)
+                result_set = topo_order[: self.limit]
+                ret = self.source_repo.revision_ids_to_search_result(result_set)
             return ret
         else:
-            return vf_search.NotInOtherForRevs(self.target_repo, self.source_repo,
-                                               required_ids=heads_to_fetch, if_present_ids=if_present_fetch,
-                                               limit=self.limit).execute()
+            return vf_search.NotInOtherForRevs(
+                self.target_repo,
+                self.source_repo,
+                required_ids=heads_to_fetch,
+                if_present_ids=if_present_fetch,
+                limit=self.limit,
+            ).execute()
