@@ -16,7 +16,6 @@
 
 import re
 import sys
-from typing import Type
 
 from ..lazy_import import lazy_import
 
@@ -44,7 +43,8 @@ from breezy.bzr.index import (
 )
 from .. import errors, lockable_files, lockdir
 from .. import transport as _mod_transport
-from ..bzr import btree_index, index
+from ..bzr import btree_index
+from ..bzr import index as _mod_index
 from ..decorators import only_raises
 from ..lock import LogicalLockResult
 from ..repository import RepositoryWriteLockResult, _LazyListJoin
@@ -69,12 +69,11 @@ class RetryWithNewPacks(errors.BzrError):
     internal_error = True
 
     _fmt = (
-        "Pack files have changed, reload and retry. context: %(context)s"
-        " %(orig_error)s"
+        "Pack files have changed, reload and retry. context: %(context)s %(orig_error)s"
     )
 
     def __init__(self, context, reload_occurred, exc_info):
-        """create a new RetryWithNewPacks error.
+        """Create a new RetryWithNewPacks error.
 
         :param reload_occurred: Set to True if we know that the packs have
             already been reloaded, and we are failing because of an in-memory
@@ -226,13 +225,13 @@ class Pack:
                 k for (idx, k, v, r) in index.iter_entries(external_refs)
             )
             if missing:
-                missing_items[index_name] = sorted(list(missing))
+                missing_items[index_name] = sorted(missing)
         if missing_items:
             from pprint import pformat
 
             raise errors.BzrCheckError(
-                "Newly created pack file %r has delta references to "
-                "items not in its repository:\n%s" % (self, pformat(missing_items))
+                "Newly created pack file {!r} has delta references to "
+                "items not in its repository:\n{}".format(self, pformat(missing_items))
             )
 
     def file_name(self):
@@ -758,7 +757,9 @@ class AggregateIndex:
         """
         if self.add_callback is not None:
             raise AssertionError(
-                "%s already has a writable index through %s" % (self, self.add_callback)
+                "{} already has a writable index through {}".format(
+                    self, self.add_callback
+                )
             )
         # allow writing: queue writes to a new index
         self.add_index(index, pack)
@@ -842,8 +843,9 @@ class Packer:
         #      considering 'done'.
         if self._pack_collection._new_pack is not None:
             raise errors.BzrError(
-                "call to %s.pack() while another pack is"
-                " being written." % (self.__class__.__name__,)
+                "call to {}.pack() while another pack is being written.".format(
+                    self.__class__.__name__
+                )
             )
         if self.revision_ids is not None:
             if len(self.revision_ids) == 0:
@@ -922,10 +924,10 @@ class RepositoryPackCollection:
     :ivar _names: map of {pack_name: (index_size,)}
     """
 
-    pack_factory: Type[NewPack]
-    resumed_pack_factory: Type[ResumedPack]
-    normal_packer_class: Type[Packer]
-    optimising_packer_class: Type[Packer]
+    pack_factory: type[NewPack]
+    resumed_pack_factory: type[ResumedPack]
+    normal_packer_class: type[Packer]
+    optimising_packer_class: type[Packer]
 
     def __init__(
         self,
@@ -1107,7 +1109,7 @@ class RepositoryPackCollection:
         :param packer_class: The class of packer to use
         :return: The new pack names.
         """
-        for revision_count, packs in pack_operations:
+        for _revision_count, packs in pack_operations:
             # we may have no-ops from the setup logic
             if len(packs) == 0:
                 continue
@@ -1245,8 +1247,7 @@ class RepositoryPackCollection:
             final_pack_list.extend(pack_files)
         if len(final_pack_list) == 1:
             raise AssertionError(
-                "We somehow generated an autopack with a"
-                " single pack file being moved."
+                "We somehow generated an autopack with a single pack file being moved."
             )
             return []
         return [[final_rev_count, final_pack_list]]
@@ -1263,7 +1264,7 @@ class RepositoryPackCollection:
         if self._names is None:
             self._names = {}
             self._packs_at_load = set()
-            for index, key, value in self._iter_disk_pack_index():
+            for _index, key, value in self._iter_disk_pack_index():
                 name = key[0].decode("ascii")
                 self._names[name] = self._parse_index_sizes(value)
                 self._packs_at_load.add((name, value))
@@ -1341,7 +1342,7 @@ class RepositoryPackCollection:
                 chk_index=chk_index,
             )
         except _mod_transport.NoSuchFile as e:
-            raise errors.UnresumableWriteGroup(self.repo, [name], str(e))
+            raise errors.UnresumableWriteGroup(self.repo, [name], str(e)) from e
         self.add_pack_to_memory(result)
         self._resumed_packs.append(result)
         return result
@@ -1434,7 +1435,7 @@ class RepositoryPackCollection:
                     )
             except (errors.PathError, errors.TransportError) as e:
                 # TODO: Should these be warnings or mutters?
-                mutter("couldn't rename obsolete pack, skipping it:\n%s" % (e,))
+                mutter("couldn't rename obsolete pack, skipping it:\n{}".format(e))
             # TODO: Probably needs to know all possible indices for this pack
             # - or maybe list the directory and move all indices matching this
             # name whether we recognize it or not?
@@ -1447,7 +1448,7 @@ class RepositoryPackCollection:
                         pack.name + suffix, "../obsolete_packs/" + pack.name + suffix
                     )
                 except (errors.PathError, errors.TransportError) as e:
-                    mutter("couldn't rename obsolete index, skipping it:\n%s" % (e,))
+                    mutter("couldn't rename obsolete index, skipping it:\n{}".format(e))
 
     def pack_distribution(self, total_revisions):
         """Generate a list of the number of revisions to put in each pack.
@@ -1461,7 +1462,7 @@ class RepositoryPackCollection:
         result = []
         for exponent, count in enumerate(digits):
             size = 10**exponent
-            for pos in range(int(count)):
+            for _pos in range(int(count)):
                 result.append(size)
         return list(reversed(result))
 
@@ -1531,7 +1532,7 @@ class RepositoryPackCollection:
         """
         # load the disk nodes across
         disk_nodes = set()
-        for index, key, value in self._iter_disk_pack_index():
+        for _index, key, value in self._iter_disk_pack_index():
             disk_nodes.add((key[0].decode("ascii"), value))
         orig_disk_nodes = set(disk_nodes)
 
@@ -1614,7 +1615,7 @@ class RepositoryPackCollection:
         self.lock_names()
         try:
             builder = self._index_builder_class()
-            (disk_nodes, deleted_nodes, new_nodes, orig_disk_nodes) = (
+            (disk_nodes, _deleted_nodes, new_nodes, _orig_disk_nodes) = (
                 self._diff_pack_names()
             )
             # TODO: handle same-name, index-size-changes here -
@@ -1667,7 +1668,7 @@ class RepositoryPackCollection:
         if first_read:
             return True
         # out the new value.
-        (disk_nodes, deleted_nodes, new_nodes, orig_disk_nodes) = (
+        (disk_nodes, _deleted_nodes, _new_nodes, orig_disk_nodes) = (
             self._diff_pack_names()
         )
         # _packs_at_load is meant to be the explicit list of names in
@@ -1677,9 +1678,7 @@ class RepositoryPackCollection:
         (removed, added, modified) = self._syncronize_pack_names_from_disk_nodes(
             disk_nodes
         )
-        if removed or added or modified:
-            return True
-        return False
+        return bool(removed or added or modified)
 
     def _restart_autopack(self):
         """Reload the pack names list, and restart the autopack code."""
@@ -1720,7 +1719,7 @@ class RepositoryPackCollection:
             try:
                 obsolete_pack_transport.delete(filename)
             except (errors.PathError, errors.TransportError) as e:
-                warning("couldn't delete obsolete pack, skipping it:\n%s" % (e,))
+                warning("couldn't delete obsolete pack, skipping it:\n{}".format(e))
         return found
 
     def _start_write_group(self):
@@ -1802,8 +1801,9 @@ class RepositoryPackCollection:
             all_missing.update([(prefix,) + key for key in missing])
         if all_missing:
             raise errors.BzrCheckError(
-                "Repository %s has missing compression parent(s) %r "
-                % (self.repo, sorted(all_missing))
+                "Repository {} has missing compression parent(s) {!r} ".format(
+                    self.repo, sorted(all_missing)
+                )
             )
         problems = self._check_new_inventories()
         if problems:
@@ -1888,7 +1888,7 @@ class PackRepository(MetaDirVersionedFileRepository):
     # them to None ensures that if the constructor is changed to not initialize
     # them, or a subclass fails to call the constructor, that an error will
     # occur rather than the system working but generating incorrect data.
-    _commit_builder_class: Type[VersionedFileCommitBuilder]
+    _commit_builder_class: type[VersionedFileCommitBuilder]
     _serializer: Serializer
 
     def __init__(
@@ -2050,7 +2050,7 @@ class PackRepository(MetaDirVersionedFileRepository):
             self._transaction = None
             self._write_lock_count = 0
             raise errors.BzrError(
-                "Must end write group before releasing write lock on %s" % self
+                "Must end write group before releasing write lock on {}".format(self)
             )
         if self._write_lock_count:
             self._write_lock_count -= 1
@@ -2084,11 +2084,11 @@ class RepositoryFormatPack(MetaDirVersionedFileRepositoryFormat):
 
     # Set this attribute in derived classes to control the repository class
     # created by open and initialize.
-    repository_class: Type[PackRepository]
+    repository_class: type[PackRepository]
     # Set this attribute in derived classes to control the
     # _commit_builder_class that the repository objects will have passed to
     # their constructor.
-    _commit_builder_class: Type[VersionedFileCommitBuilder]
+    _commit_builder_class: type[VersionedFileCommitBuilder]
     # Set this attribute in derived clases to control the _serializer that the
     # repository objects will have passed to their constructor.
     _serializer: Serializer
@@ -2099,8 +2099,8 @@ class RepositoryFormatPack(MetaDirVersionedFileRepositoryFormat):
     # Most pack formats do not use chk lookups.
     supports_chks: bool = False
     # What index classes to use
-    index_builder_class: Type[index.GraphIndexBuilder]
-    index_class: Type[object]
+    index_builder_class: type[_mod_index.GraphIndexBuilder]
+    index_class: type[object]
     _fetch_uses_deltas: bool = True
     fast_deltas: bool = False
     supports_funky_characters: bool = True
@@ -2133,7 +2133,7 @@ class RepositoryFormatPack(MetaDirVersionedFileRepositoryFormat):
                                     than normal. I.e. during 'upgrade'.
         """
         if not _found:
-            format = RepositoryFormatMetaDir.find_format(a_controldir)
+            RepositoryFormatMetaDir.find_format(a_controldir)
         if _override_transport is not None:
             repo_transport = _override_transport
         else:
@@ -2215,7 +2215,9 @@ class _DirectPackAccess:
         """
         raw_data = b"".join(raw_data)
         if not isinstance(raw_data, bytes):
-            raise AssertionError("data must be plain bytes was %s" % type(raw_data))
+            raise AssertionError(
+                "data must be plain bytes was {}".format(type(raw_data))
+            )
         result = []
         offset = 0
         for key, size in key_sizes:
@@ -2259,7 +2261,7 @@ class _DirectPackAccess:
         for index, offsets in request_lists:
             try:
                 transport, path = self._indices[index]
-            except KeyError:
+            except KeyError as e:
                 # A KeyError here indicates that someone has triggered an index
                 # reload, and this index has gone missing, we need to start
                 # over.
@@ -2269,12 +2271,12 @@ class _DirectPackAccess:
                     raise
                 raise RetryWithNewPacks(
                     index, reload_occurred=True, exc_info=sys.exc_info()
-                )
+                ) from e
             try:
                 reader = pack.make_readv_reader(transport, path, offsets)
-                for names, read_func in reader.iter_records():
+                for _names, read_func in reader.iter_records():
                     yield read_func(None)
-            except _mod_transport.NoSuchFile:
+            except _mod_transport.NoSuchFile as e:
                 # A NoSuchFile error indicates that a pack file has gone
                 # missing on disk, we need to trigger a reload, and start over.
                 if self._reload_func is None:
@@ -2283,7 +2285,7 @@ class _DirectPackAccess:
                     transport.abspath(path),
                     reload_occurred=False,
                     exc_info=sys.exc_info(),
-                )
+                ) from e
 
     def set_writer(self, writer, index, transport_packname):
         """Set a writer to use for adding data."""
