@@ -14,20 +14,16 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-from __future__ import absolute_import
-
-from . import (
-    xml6,
-    )
+from . import xml6
 
 
 class Serializer_v7(xml6.Serializer_v6):
-    """A Serializer that supports tree references"""
+    """A Serializer that supports tree references."""
 
     # this format is used by BzrBranch6
 
-    supported_kinds = {'file', 'directory', 'symlink', 'tree-reference'}
-    format_num = b'7'
+    supported_kinds = {"file", "directory", "symlink", "tree-reference"}
+    format_num = b"7"
 
 
 serializer_v7 = Serializer_v7()
