@@ -21,7 +21,6 @@ import contextlib
 from collections import defaultdict
 from functools import partial
 from io import BytesIO
-from typing import Optional
 
 from dulwich.config import ConfigFile as GitConfigFile
 from dulwich.config import parse_submodules
@@ -111,7 +110,7 @@ class InterTagsFromGitToRemoteGit(InterTags):
         self,
         overwrite: bool = False,
         ignore_master: bool = False,
-        selector: Optional[TagSelector] = None,
+        selector: TagSelector | None = None,
     ) -> tuple[TagUpdates, set[TagConflict]]:
         if self.source.branch.repository.has_same_location(
             self.target.branch.repository
@@ -340,7 +339,7 @@ class LocalGitTagDict(GitTags):
 
     def set_tag(self, name, revid):
         try:
-            git_sha, mapping = self.branch.lookup_bzr_revision_id(revid)
+            git_sha, _mapping = self.branch.lookup_bzr_revision_id(revid)
         except errors.NoSuchRevision:
             raise errors.GhostTagsNotSupported(self)
         self.refs[tag_name_to_ref(name)] = git_sha
@@ -1026,7 +1025,7 @@ class InterFromGitBranch(branch.GenericInterBranch):
             c = self.source.get_config_stack()
             fetch_tags = c.get("branch.fetch_tags")
 
-        def determine_wants(heads):
+        def determine_wants(heads, depth=None):
             if stop_revision is None:
                 try:
                     head = heads[self.source.ref]
@@ -1093,7 +1092,7 @@ class InterFromGitBranch(branch.GenericInterBranch):
             # We assume that during 'pull' the target repository is closer than
             # the source one.
             (result.old_revno, result.old_revid) = self.target.last_revision_info()
-            result.new_git_head, remote_refs = self._update_revisions(
+            result.new_git_head, _remote_refs = self._update_revisions(
                 stop_revision,
                 overwrite=("history" in overwrite),
                 tag_selector=tag_selector,
@@ -1186,7 +1185,7 @@ class InterFromGitBranch(branch.GenericInterBranch):
         result.source_branch = self.source
         result.target_branch = self.target
         result.old_revno, result.old_revid = self.target.last_revision_info()
-        result.new_git_head, remote_refs = self._update_revisions(
+        result.new_git_head, _remote_refs = self._update_revisions(
             stop_revision, overwrite=("history" in overwrite), tag_selector=tag_selector
         )
         tags_ret = self.source.tags.merge_to(
@@ -1259,16 +1258,8 @@ class InterLocalGitRemoteGitBranch(InterGitBranch):
                 refs[tag_name_to_ref(name)] = sha
             return refs
 
-        # Wrapper to adapt dulwich Repo.generate_pack_data signature for dulwich >= 0.22
-        # Client expects: (have, want, ofs_delta)
-        # Repo provides: (have, want, progress=None, ofs_delta=None)
-        def generate_pack_data_wrapper(have, want, ofs_delta=True):
-            return self.source.repository._git.generate_pack_data(
-                have, want, progress=None, ofs_delta=ofs_delta
-            )
-
         dw_result = self.target.repository.send_pack(
-            get_changed_refs, generate_pack_data_wrapper
+            get_changed_refs, self.source.repository._git.generate_pack_data
         )
         if dw_result is not None and not isinstance(dw_result, dict):
             error = dw_result.ref_status.get(self.target.ref)
@@ -1324,7 +1315,7 @@ class InterGitLocalGitBranch(InterGitBranch):
         result.source_branch = self.source
         result.target_branch = self.target
         result.old_revid = self.target.last_revision()
-        refs, stop_revision = self.update_refs(stop_revision)
+        _refs, stop_revision = self.update_refs(stop_revision)
         _update_tip(self.source, self.target, stop_revision, "history" in overwrite)
         tags_ret = self.source.tags.merge_to(
             self.target.tags, overwrite=("tags" in overwrite), selector=tag_selector
@@ -1382,7 +1373,7 @@ class InterGitLocalGitBranch(InterGitBranch):
         result.target_branch = self.target
         with self.target.lock_write(), self.source.lock_read():
             result.old_revid = self.target.last_revision()
-            refs, stop_revision = self.update_refs(stop_revision)
+            _refs, stop_revision = self.update_refs(stop_revision)
             _update_tip(self.source, self.target, stop_revision, "history" in overwrite)
             tags_ret = self.source.tags.merge_to(
                 self.target.tags, overwrite=("tags" in overwrite), selector=tag_selector
@@ -1548,11 +1539,11 @@ class InterToGitBranch(branch.GenericInterBranch):
             )
         else:
 
-            def determine_wants(refs):
+            def determine_wants(refs, depth=None):
                 wants = []
                 for git_sha, revid in ret:
                     if git_sha is None:
-                        git_sha, mapping = self.target.lookup_bzr_revision_id(revid)
+                        git_sha, _mapping = self.target.lookup_bzr_revision_id(revid)
                     wants.append(git_sha)
                 return wants
 
@@ -1573,7 +1564,7 @@ class InterToGitBranch(branch.GenericInterBranch):
         result.source_branch = self.source
         result.target_branch = self.target
         with self.source.lock_read(), self.target.lock_write():
-            new_refs, main_ref, stop_revinfo = self._get_new_refs(
+            new_refs, main_ref, _stop_revinfo = self._get_new_refs(
                 stop_revision, stop_revno=_stop_revno
             )
 
