@@ -1,5 +1,4 @@
 # Copyright (C) 2009-2018 Jelmer Vernooij <jelmer@jelmer.uk>
-# -*- coding: utf-8 -*-
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,58 +16,26 @@
 
 """Tests from fetching from git into bzr."""
 
-from dulwich.objects import (
-    Blob,
-    Tag,
-    Tree,
-    S_IFGITLINK,
-    )
-from dulwich.repo import (
-    Repo as GitRepo,
-    )
 import os
 import stat
 import time
 
-from ... import (
-    osutils,
-    )
-from ...bzr import (
-    knit,
-    versionedfile,
-    )
-from ...branch import (
-    Branch,
-    )
-from ...controldir import (
-    ControlDir,
-    )
-from ...bzr.inventory import (
-    Inventory,
-    )
-from ...repository import (
-    Repository,
-    )
-from ...tests import (
-    TestCaseWithTransport,
-    )
+from dulwich.objects import S_IFGITLINK, Blob, Tag, Tree
+from dulwich.repo import Repo as GitRepo
 
-from ..fetch import (
-    import_git_blob,
-    import_git_tree,
-    import_git_submodule,
-    )
-from ..mapping import (
-    BzrGitMappingv1,
-    DEFAULT_FILE_MODE,
-    )
-from . import (
-    GitBranchBuilder,
-    )
+from ... import osutils
+from ...branch import Branch
+from ...bzr import knit, versionedfile
+from ...bzr.inventory import Inventory
+from ...controldir import ControlDir
+from ...repository import Repository
+from ...tests import TestCaseWithTransport
+from ..fetch import import_git_blob, import_git_submodule, import_git_tree
+from ..mapping import DEFAULT_FILE_MODE, BzrGitMappingv1
+from . import GitBranchBuilder
 
 
-class RepositoryFetchTests(object):
-
+class RepositoryFetchTests:
     def make_git_repo(self, path):
         os.mkdir(path)
         return GitRepo.init(os.path.abspath(path))
@@ -127,8 +94,7 @@ class RepositoryFetchTests(object):
         self.assertEqual([revid1], newrepo.all_revision_ids())
         revid2 = oldrepo.get_mapping().revision_id_foreign_to_bzr(gitsha2)
         newrepo.fetch(oldrepo, revision_id=revid2)
-        self.assertEqual(set([revid1, revid2]),
-                         set(newrepo.all_revision_ids()))
+        self.assertEqual({revid1, revid2}, set(newrepo.all_revision_ids()))
 
     def test_dir_becomes_symlink(self):
         self.make_git_repo("d")
@@ -228,7 +194,7 @@ class RepositoryFetchTests(object):
         os.chdir("d")
         bb = GitBranchBuilder()
         bb.set_file("foobar", b"foo\nbar\n", False)
-        mark1 = bb.commit(b"Somebody <somebody@someorg.org>", b"mymsg")
+        bb.commit(b"Somebody <somebody@someorg.org>", b"mymsg")
         bb.set_file("foobar", b"foo\nbar\n", True)
         mark2 = bb.commit(b"Somebody <somebody@someorg.org>", b"mymsg")
         gitsha2 = bb.finish()[mark2]
@@ -242,10 +208,10 @@ class RepositoryFetchTests(object):
         self.assertEqual(revid, tree.get_file_revision("foobar"))
 
     def test_into_stacked_on(self):
-        r = self.make_git_repo("d")
+        self.make_git_repo("d")
         os.chdir("d")
         bb = GitBranchBuilder()
-        bb.set_file(u"foobar", b"foo\n", False)
+        bb.set_file("foobar", b"foo\n", False)
         mark1 = bb.commit(b"Somebody <somebody@someorg.org>", b"mymsg1")
         gitsha1 = bb.finish()[mark1]
         os.chdir("..")
@@ -260,8 +226,8 @@ class RepositoryFetchTests(object):
         tree.branch.set_stacked_on_url(b.user_url)
         os.chdir("d")
         bb = GitBranchBuilder()
-        bb.set_file(u"barbar", b"bar\n", False)
-        bb.set_file(u"foo/blie/bla", b"bla\n", False)
+        bb.set_file("barbar", b"bar\n", False)
+        bb.set_file("foo/blie/bla", b"bla\n", False)
         mark2 = bb.commit(b"Somebody <somebody@someorg.org>", b"mymsg2")
         gitsha2 = bb.finish()[mark2]
         revid2 = oldrepo.get_mapping().revision_id_foreign_to_bzr(gitsha2)
@@ -270,17 +236,17 @@ class RepositoryFetchTests(object):
         tree.branch.repository.check()
         self.addCleanup(tree.lock_read().unlock)
         self.assertEqual(
-            set([(revid2,)]),
-            tree.branch.repository.revisions.without_fallbacks().keys())
+            {(revid2,)}, tree.branch.repository.revisions.without_fallbacks().keys()
+        )
         self.assertEqual(
-            set([revid1, revid2]),
-            set(tree.branch.repository.all_revision_ids()))
+            {revid1, revid2}, set(tree.branch.repository.all_revision_ids())
+        )
 
     def test_non_ascii_characters(self):
         self.make_git_repo("d")
         os.chdir("d")
         bb = GitBranchBuilder()
-        bb.set_file(u"foőbar", b"foo\nbar\n", False)
+        bb.set_file("foőbar", b"foo\nbar\n", False)
         mark = bb.commit(b"Somebody <somebody@someorg.org>", b"mymsg")
         gitsha = bb.finish()[mark]
         os.chdir("..")
@@ -288,7 +254,7 @@ class RepositoryFetchTests(object):
         newrepo = self.clone_git_repo("d", "f")
         revid = oldrepo.get_mapping().revision_id_foreign_to_bzr(gitsha)
         tree = newrepo.revision_tree(revid)
-        self.assertTrue(tree.has_filename(u"foőbar"))
+        self.assertTrue(tree.has_filename("foőbar"))
 
     def test_tagged_tree(self):
         r = self.make_git_repo("d")
@@ -311,17 +277,15 @@ class RepositoryFetchTests(object):
         oldrepo = self.open_git_repo("d")
         revid = oldrepo.get_mapping().revision_id_foreign_to_bzr(gitsha)
         newrepo = self.clone_git_repo("d", "f")
-        self.assertEqual(set([revid]), set(newrepo.all_revision_ids()))
+        self.assertEqual({revid}, set(newrepo.all_revision_ids()))
 
 
 class LocalRepositoryFetchTests(RepositoryFetchTests, TestCaseWithTransport):
-
     def open_git_repo(self, path):
         return Repository.open(path)
 
 
-class DummyStoreUpdater(object):
-
+class DummyStoreUpdater:
     def add_object(self, obj, ie, path):
         pass
 
@@ -330,48 +294,77 @@ class DummyStoreUpdater(object):
 
 
 class ImportObjects(TestCaseWithTransport):
-
     def setUp(self):
-        super(ImportObjects, self).setUp()
+        super().setUp()
         self._mapping = BzrGitMappingv1()
         factory = knit.make_file_factory(True, versionedfile.PrefixMapper())
-        self._texts = factory(self.get_transport('texts'))
+        self._texts = factory(self.get_transport("texts"))
 
     def test_import_blob_missing_in_one_parent(self):
-        builder = self.make_branch_builder('br')
+        builder = self.make_branch_builder("br")
         builder.start_series()
-        rev_root = builder.build_snapshot(None, [
-            ('add', ('', b'rootid', 'directory', ''))])
-        rev1 = builder.build_snapshot([rev_root], [
-            ('add', ('bla', self._mapping.generate_file_id('bla'), 'file', b'content'))])
+        rev_root = builder.build_snapshot(
+            None, [("add", ("", b"rootid", "directory", ""))]
+        )
+        rev1 = builder.build_snapshot(
+            [rev_root],
+            [
+                (
+                    "add",
+                    ("bla", self._mapping.generate_file_id("bla"), "file", b"content"),
+                )
+            ],
+        )
         rev2 = builder.build_snapshot([rev_root], [])
         builder.finish_series()
         branch = builder.get_branch()
 
         blob = Blob.from_string(b"bar")
         objs = {"blobname": blob}
-        ret = import_git_blob(self._texts, self._mapping, b"bla", b"bla",
-                              (None, "blobname"),
-                              branch.repository.revision_tree(
-                                  rev1), b'rootid', b"somerevid",
-                              [branch.repository.revision_tree(r) for r in [
-                                  rev1, rev2]],
-                              objs.__getitem__,
-                              (None, DEFAULT_FILE_MODE), DummyStoreUpdater(),
-                              self._mapping.generate_file_id)
-        self.assertEqual(set([(b'git:bla', b'somerevid')]), self._texts.keys())
+        import_git_blob(
+            self._texts,
+            self._mapping,
+            b"bla",
+            b"bla",
+            (None, "blobname"),
+            branch.repository.revision_tree(rev1),
+            b"rootid",
+            b"somerevid",
+            [branch.repository.revision_tree(r) for r in [rev1, rev2]],
+            objs.__getitem__,
+            (None, DEFAULT_FILE_MODE),
+            DummyStoreUpdater(),
+            self._mapping.generate_file_id,
+        )
+        self.assertEqual({(b"git:bla", b"somerevid")}, self._texts.keys())
 
     def test_import_blob_simple(self):
         blob = Blob.from_string(b"bar")
         objs = {"blobname": blob}
-        ret = import_git_blob(self._texts, self._mapping, b"bla", b"bla",
-                              (None, "blobname"),
-                              None, None, b"somerevid", [], objs.__getitem__,
-                              (None, DEFAULT_FILE_MODE), DummyStoreUpdater(),
-                              self._mapping.generate_file_id)
-        self.assertEqual(set([(b'git:bla', b'somerevid')]), self._texts.keys())
-        self.assertEqual(next(self._texts.get_record_stream([(b'git:bla', b'somerevid')],
-                                                            "unordered", True)).get_bytes_as("fulltext"), b"bar")
+        ret = import_git_blob(
+            self._texts,
+            self._mapping,
+            b"bla",
+            b"bla",
+            (None, "blobname"),
+            None,
+            None,
+            b"somerevid",
+            [],
+            objs.__getitem__,
+            (None, DEFAULT_FILE_MODE),
+            DummyStoreUpdater(),
+            self._mapping.generate_file_id,
+        )
+        self.assertEqual({(b"git:bla", b"somerevid")}, self._texts.keys())
+        self.assertEqual(
+            next(
+                self._texts.get_record_stream(
+                    [(b"git:bla", b"somerevid")], "unordered", True
+                )
+            ).get_bytes_as("fulltext"),
+            b"bar",
+        )
         self.assertEqual(1, len(ret))
         self.assertEqual(None, ret[0][0])
         self.assertEqual("bla", ret[0][1])
@@ -383,15 +376,23 @@ class ImportObjects(TestCaseWithTransport):
 
     def test_import_tree_empty_root(self):
         tree = Tree()
-        ret, child_modes = import_git_tree(self._texts, self._mapping, b"", b"",
-                                           (None, tree.id), None,
-                                           None, b"somerevid", [], {
-                                               tree.id: tree}.__getitem__,
-                                           (None, stat.S_IFDIR), DummyStoreUpdater(),
-                                           self._mapping.generate_file_id)
+        ret, child_modes = import_git_tree(
+            self._texts,
+            self._mapping,
+            b"",
+            b"",
+            (None, tree.id),
+            None,
+            None,
+            b"somerevid",
+            [],
+            {tree.id: tree}.__getitem__,
+            (None, stat.S_IFDIR),
+            DummyStoreUpdater(),
+            self._mapping.generate_file_id,
+        )
         self.assertEqual(child_modes, {})
-        self.assertEqual(
-            set([(b"TREE_ROOT", b'somerevid')]), self._texts.keys())
+        self.assertEqual({(b"TREE_ROOT", b"somerevid")}, self._texts.keys())
         self.assertEqual(1, len(ret))
         self.assertEqual(None, ret[0][0])
         self.assertEqual("", ret[0][1])
@@ -404,13 +405,23 @@ class ImportObjects(TestCaseWithTransport):
 
     def test_import_tree_empty(self):
         tree = Tree()
-        ret, child_modes = import_git_tree(self._texts, self._mapping, b"bla", b"bla",
-                                           (None, tree.id), None, None, b"somerevid", [],
-                                           {tree.id: tree}.__getitem__,
-                                           (None, stat.S_IFDIR), DummyStoreUpdater(),
-                                           self._mapping.generate_file_id)
+        ret, child_modes = import_git_tree(
+            self._texts,
+            self._mapping,
+            b"bla",
+            b"bla",
+            (None, tree.id),
+            None,
+            None,
+            b"somerevid",
+            [],
+            {tree.id: tree}.__getitem__,
+            (None, stat.S_IFDIR),
+            DummyStoreUpdater(),
+            self._mapping.generate_file_id,
+        )
         self.assertEqual(child_modes, {})
-        self.assertEqual(set([(b"git:bla", b'somerevid')]), self._texts.keys())
+        self.assertEqual({(b"git:bla", b"somerevid")}, self._texts.keys())
         self.assertEqual(1, len(ret))
         self.assertEqual(None, ret[0][0])
         self.assertEqual("bla", ret[0][1])
@@ -426,11 +437,21 @@ class ImportObjects(TestCaseWithTransport):
         tree = Tree()
         tree.add(b"foo", stat.S_IFREG | 0o644, blob.id)
         objects = {blob.id: blob, tree.id: tree}
-        ret, child_modes = import_git_tree(self._texts, self._mapping, b"bla", b"bla",
-                                           (None, tree.id), None, None, b"somerevid", [],
-                                           objects.__getitem__, (None, stat.S_IFDIR), DummyStoreUpdater(
-                                           ),
-                                           self._mapping.generate_file_id)
+        ret, child_modes = import_git_tree(
+            self._texts,
+            self._mapping,
+            b"bla",
+            b"bla",
+            (None, tree.id),
+            None,
+            None,
+            b"somerevid",
+            [],
+            objects.__getitem__,
+            (None, stat.S_IFDIR),
+            DummyStoreUpdater(),
+            self._mapping.generate_file_id,
+        )
         self.assertEqual(child_modes, {})
         self.assertEqual(2, len(ret))
         self.assertEqual(None, ret[0][0])
@@ -451,12 +472,21 @@ class ImportObjects(TestCaseWithTransport):
         tree = Tree()
         tree.add(b"foo", stat.S_IFREG | 0o664, blob.id)
         objects = {blob.id: blob, tree.id: tree}
-        ret, child_modes = import_git_tree(self._texts, self._mapping,
-                                           b"bla", b"bla", (None, tree.id), None, None, b"somerevid", [
-                                               ],
-                                           objects.__getitem__, (None, stat.S_IFDIR), DummyStoreUpdater(
-                                           ),
-                                           self._mapping.generate_file_id)
+        _ret, child_modes = import_git_tree(
+            self._texts,
+            self._mapping,
+            b"bla",
+            b"bla",
+            (None, tree.id),
+            None,
+            None,
+            b"somerevid",
+            [],
+            objects.__getitem__,
+            (None, stat.S_IFDIR),
+            DummyStoreUpdater(),
+            self._mapping.generate_file_id,
+        )
         self.assertEqual(child_modes, {b"bla/foo": stat.S_IFREG | 0o664})
 
     def test_import_tree_with_file_exe(self):
@@ -464,11 +494,21 @@ class ImportObjects(TestCaseWithTransport):
         tree = Tree()
         tree.add(b"foo", 0o100755, blob.id)
         objects = {blob.id: blob, tree.id: tree}
-        ret, child_modes = import_git_tree(self._texts, self._mapping, b"", b"",
-                                           (None, tree.id), None, None, b"somerevid", [],
-                                           objects.__getitem__, (None, stat.S_IFDIR), DummyStoreUpdater(
-                                           ),
-                                           self._mapping.generate_file_id)
+        ret, child_modes = import_git_tree(
+            self._texts,
+            self._mapping,
+            b"",
+            b"",
+            (None, tree.id),
+            None,
+            None,
+            b"somerevid",
+            [],
+            objects.__getitem__,
+            (None, stat.S_IFDIR),
+            DummyStoreUpdater(),
+            self._mapping.generate_file_id,
+        )
         self.assertEqual(child_modes, {})
         self.assertEqual(2, len(ret))
         self.assertEqual(None, ret[0][0])
@@ -490,17 +530,26 @@ class ImportObjects(TestCaseWithTransport):
         tree = Tree()
         tree.add(b"bar", 0o160000, blob.id)
         objects = {tree.id: tree}
-        ret, child_modes = import_git_submodule(self._texts, self._mapping, b"foo", b"foo",
-                                                (tree.id, othertree.id), base_inv, base_inv.root.file_id, b"somerevid", [
-                                                    ],
-                                                objects.__getitem__, (stat.S_IFDIR | 0o755, S_IFGITLINK), DummyStoreUpdater(
-                                                ),
-                                                self._mapping.generate_file_id)
+        ret, child_modes = import_git_submodule(
+            self._texts,
+            self._mapping,
+            b"foo",
+            b"foo",
+            (tree.id, othertree.id),
+            base_inv,
+            base_inv.root.file_id,
+            b"somerevid",
+            [],
+            objects.__getitem__,
+            (stat.S_IFDIR | 0o755, S_IFGITLINK),
+            DummyStoreUpdater(),
+            self._mapping.generate_file_id,
+        )
         self.assertEqual(child_modes, {})
         self.assertEqual(2, len(ret))
+        self.assertEqual(ret[0], ("foo/bar", None, base_inv.path2id("foo/bar"), None))
         self.assertEqual(
-            ret[0], ("foo/bar", None, base_inv.path2id("foo/bar"), None))
-        self.assertEqual(ret[1][:3], ("foo", "foo",
-                                      self._mapping.generate_file_id("foo")))
+            ret[1][:3], ("foo", "foo", self._mapping.generate_file_id("foo"))
+        )
         ie = ret[1][3]
         self.assertEqual(ie.kind, "tree-reference")
