@@ -21,8 +21,8 @@ import re
 import stat
 import sys
 import time
+from collections.abc import Callable
 from functools import partial
-from typing import Callable
 
 from .lazy_import import lazy_import
 
@@ -1488,7 +1488,7 @@ def terminal_width():
         return None
 
     # Query the OS
-    width, height = os_size = _terminal_size(None, None)
+    width, _height = os_size = _terminal_size(None, None)
     global _first_terminal_size, _terminal_size_state
     if _terminal_size_state == "no_data":
         _first_terminal_size = os_size
@@ -2078,7 +2078,7 @@ def connect_socket(address):
     err = socket.error("getaddrinfo returns an empty list")
     host, port = address
     for res in socket.getaddrinfo(host, port, 0, socket.SOCK_STREAM):
-        af, socktype, proto, canonname, sa = res
+        af, socktype, proto, _canonname, sa = res
         sock = None
         try:
             sock = socket.socket(af, socktype, proto)
