@@ -17,36 +17,33 @@
 __doc__ = """Use ~/.netrc as a credential store for authentication.conf."""
 
 # Since we are a built-in plugin we share the breezy version
-from ... import version_info  # noqa: F401
-
 from ... import (
     config,
-    errors,
-    lazy_import,
-    transport as _mod_transport,
-    )
+    version_info,  # noqa: F401
+)
+from ... import transport as _mod_transport
 
 
 class NetrcCredentialStore(config.CredentialStore):
-
     def __init__(self):
-        super(NetrcCredentialStore, self).__init__()
-        import netrc
+        super().__init__()
         import errno
+        import netrc
+
         try:
             self._netrc = netrc.netrc()
-        except IOError as e:
+        except OSError as e:
             if e.args[0] == errno.ENOENT:
                 raise _mod_transport.NoSuchFile(e.filename)
             else:
                 raise
 
     def decode_password(self, credentials):
-        auth = self._netrc.authenticators(credentials['host'])
+        auth = self._netrc.authenticators(credentials["host"])
         password = None
         if auth is not None:
-            user, account, password = auth
-            cred_user = credentials.get('user', None)
+            user, _account, password = auth
+            cred_user = credentials.get("user", None)
             if cred_user is None or user != cred_user:
                 # We don't use the netrc ability to provide a user since there
                 # is no way to give it back to AuthConfig. So if the user
@@ -56,13 +53,17 @@ class NetrcCredentialStore(config.CredentialStore):
 
 
 config.credential_store_registry.register_lazy(
-    'netrc', __name__, 'NetrcCredentialStore', help=__doc__)
+    "netrc", __name__, "NetrcCredentialStore", help=__doc__
+)
 
 
 def load_tests(loader, basic_tests, pattern):
     testmod_names = [
-        'tests',
-        ]
-    basic_tests.addTest(loader.loadTestsFromModuleNames(
-        ["%s.%s" % (__name__, tmn) for tmn in testmod_names]))
+        "tests",
+    ]
+    basic_tests.addTest(
+        loader.loadTestsFromModuleNames(
+            ["{}.{}".format(__name__, tmn) for tmn in testmod_names]
+        )
+    )
     return basic_tests
