@@ -14,7 +14,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-"""Test that brz handles locales in a reasonable way"""
+"""Test that brz handles locales in a reasonable way."""
 
 import sys
 import unittest
@@ -27,9 +27,7 @@ class TestLocale(tests.TestCaseWithTransport):
         super().setUp()
 
         if sys.platform in ("win32",):
-            raise tests.TestSkipped(
-                "Windows does not respond to the LANG" " env variable"
-            )
+            raise tests.TestSkipped("Windows does not respond to the LANG env variable")
 
         tree = self.make_branch_and_tree("tree")
         self.build_tree(["tree/a"])
@@ -37,13 +35,15 @@ class TestLocale(tests.TestCaseWithTransport):
         tree.commit(
             "Unicode \xb5 commit",
             rev_id=b"r1",
-            committer="\u062c\u0648\u062c\u0648" " Meinel <juju@info.com>",
+            committer="\u062c\u0648\u062c\u0648 Meinel <juju@info.com>",
             timestamp=1156451297.96,
             timezone=0,
         )
         self.tree = tree
 
-    def run_log_quiet_long(self, args, env_changes={}):
+    def run_log_quiet_long(self, args, env_changes=None):
+        if env_changes is None:
+            env_changes = {}
         cmd = [
             "--no-aliases",
             "--no-plugins",
@@ -150,11 +150,11 @@ message:
 
 
 class TestMultibyteCodecs(tests.TestCaseWithTransport):
-    """Tests for quirks of multibyte encodings and their python codecs"""
+    """Tests for quirks of multibyte encodings and their python codecs."""
 
     def test_plugins_mbcs(self):
-        """Ensure the plugins command works with cjkcodecs, see lp:754082"""
+        """Ensure the plugins command works with cjkcodecs, see lp:754082."""
         self.disable_missing_extensions_warning()
-        out, err = self.run_bzr(["plugins"], encoding="EUC-JP")
+        _out, err = self.run_bzr(["plugins"], encoding="EUC-JP")
         # The output is tested in bt.test_plugins rather than here
         self.assertEqual("", err)
