@@ -22,19 +22,16 @@ tests are not using self.capture. If we add tests for the programmatic
 interface later, they will be non blackbox tests.
 """
 
-import codecs
 import sys
 from io import BytesIO, StringIO
 from os import chdir, mkdir, rmdir, unlink
 
-import breezy.branch
 from breezy.bzr import bzrdir, conflicts
 
 from ... import errors, osutils, status
 from ...osutils import pathjoin
 from ...revisionspec import RevisionSpec
 from ...status import show_tree_status
-from ...workingtree import WorkingTree
 from .. import TestCaseWithTransport, TestSkipped
 
 
@@ -89,7 +86,7 @@ class BranchStatus(TestCaseWithTransport):
         return uio.getvalue().decode("utf-8")
 
     def test_branch_status(self):
-        """Test basic branch status"""
+        """Test basic branch status."""
         wt = self.make_branch_and_tree(".")
 
         # status with no commits or files - it must
@@ -170,7 +167,7 @@ class BranchStatus(TestCaseWithTransport):
         )
 
     def test_branch_status_revisions(self):
-        """Tests branch status with revisions"""
+        """Tests branch status with revisions."""
         wt = self.make_branch_and_tree(".")
 
         self.build_tree(["hello.c", "bye.c"])
@@ -197,13 +194,13 @@ class BranchStatus(TestCaseWithTransport):
         )
 
     def test_pending(self):
-        """Pending merges display works, including Unicode"""
+        """Pending merges display works, including Unicode."""
         mkdir("./branch")
         wt = self.make_branch_and_tree("branch")
         b = wt.branch
         wt.commit("Empty commit 1")
         b_2_dir = b.controldir.sprout("./copy")
-        b_2 = b_2_dir.open_branch()
+        b_2_dir.open_branch()
         wt2 = b_2_dir.open_workingtree()
         wt.commit("\N{TIBETAN DIGIT TWO} Empty commit 2")
         wt2.merge_from_branch(wt.branch)
@@ -220,7 +217,7 @@ class BranchStatus(TestCaseWithTransport):
         self.assertEndsWith(message, "...\n")
 
     def test_tree_status_ignores(self):
-        """Tests branch status with ignores"""
+        """Tests branch status with ignores."""
         wt = self.make_branch_and_tree(".")
         self.run_bzr("ignore *~")
         wt.commit("commit .bzrignore")
@@ -241,9 +238,8 @@ class BranchStatus(TestCaseWithTransport):
         )
 
     def test_tree_status_specific_files(self):
-        """Tests branch status with given specific files"""
+        """Tests branch status with given specific files."""
         wt = self.make_branch_and_tree(".")
-        b = wt.branch
 
         self.build_tree(
             ["directory/", "directory/hello.c", "bye.c", "test.c", "dir2/", "missing.c"]
@@ -423,7 +419,7 @@ class BranchStatus(TestCaseWithTransport):
 
     def test_status_nonexistent_file_with_others(self):
         # brz st [--short] NONEXISTENT ...others..
-        wt = self._prepare_nonexistent()
+        self._prepare_nonexistent()
         expected = [
             "removed:\n",
             "  FILE_E\n",
@@ -434,7 +430,7 @@ class BranchStatus(TestCaseWithTransport):
             "  NONEXISTENT\n",
         ]
         out, err = self.run_bzr(
-            "status NONEXISTENT " "FILE_A FILE_B FILE_C FILE_D FILE_E", retcode=3
+            "status NONEXISTENT FILE_A FILE_B FILE_C FILE_D FILE_E", retcode=3
         )
         self.assertEqual(expected, out.splitlines(True))
         self.assertContainsRe(err, r".*ERROR: Path\(s\) do not exist: " "NONEXISTENT.*")
@@ -445,7 +441,7 @@ class BranchStatus(TestCaseWithTransport):
             "X   NONEXISTENT\n",
         ]
         out, err = self.run_bzr(
-            "status --short NONEXISTENT " "FILE_A FILE_B FILE_C FILE_D FILE_E",
+            "status --short NONEXISTENT FILE_A FILE_B FILE_C FILE_D FILE_E",
             retcode=3,
         )
         self.assertEqual(expected, out.splitlines(True))
@@ -453,7 +449,7 @@ class BranchStatus(TestCaseWithTransport):
 
     def test_status_multiple_nonexistent_files(self):
         # brz st [--short] NONEXISTENT ... ANOTHER_NONEXISTENT ...
-        wt = self._prepare_nonexistent()
+        self._prepare_nonexistent()
         expected = [
             "removed:\n",
             "  FILE_E\n",
@@ -465,9 +461,7 @@ class BranchStatus(TestCaseWithTransport):
             "  NONEXISTENT\n",
         ]
         out, err = self.run_bzr(
-            "status NONEXISTENT "
-            "FILE_A FILE_B ANOTHER_NONEXISTENT "
-            "FILE_C FILE_D FILE_E",
+            "status NONEXISTENT FILE_A FILE_B ANOTHER_NONEXISTENT FILE_C FILE_D FILE_E",
             retcode=3,
         )
         self.assertEqual(expected, out.splitlines(True))
@@ -496,7 +490,7 @@ class BranchStatus(TestCaseWithTransport):
 
     def test_status_nonexistent_file_with_unversioned(self):
         # brz st [--short] NONEXISTENT A B UNVERSIONED_BUT_EXISTING C D E Q
-        wt = self._prepare_nonexistent()
+        self._prepare_nonexistent()
         expected = [
             "removed:\n",
             "  FILE_E\n",
@@ -540,7 +534,7 @@ class BranchStatus(TestCaseWithTransport):
         self.assertContainsRe(err, r".*ERROR: Path\(s\) do not exist: " "NONEXISTENT.*")
 
     def test_status_out_of_date(self):
-        """Simulate status of out-of-date tree after remote push"""
+        """Simulate status of out-of-date tree after remote push."""
         tree = self.make_branch_and_tree(".")
         self.build_tree_contents([("a", b"foo\n")])
         with tree.lock_write():
@@ -548,7 +542,7 @@ class BranchStatus(TestCaseWithTransport):
             tree.commit("add test file")
             # simulate what happens after a remote push
             tree.set_last_revision(b"0")
-        out, err = self.run_bzr("status")
+        _out, err = self.run_bzr("status")
         self.assertEqual("working tree is out of date, run 'brz update'\n", err)
 
     def test_status_on_ignored(self):
@@ -556,7 +550,7 @@ class BranchStatus(TestCaseWithTransport):
 
         See https://bugs.launchpad.net/bzr/+bug/40103
         """
-        tree = self.make_branch_and_tree(".")
+        self.make_branch_and_tree(".")
 
         self.build_tree(["test1.c", "test1.c~", "test2.c~"])
         result = self.run_bzr("status")[0]
@@ -600,7 +594,7 @@ class BranchStatus(TestCaseWithTransport):
         wt.commit("Empty commit 1")
         wt2 = b.controldir.sprout("branch2").open_workingtree()
         wt2.commit("Empty commit 2")
-        out, err = self.run_bzr("status branch1 -rbranch:branch2")
+        out, _err = self.run_bzr("status branch1 -rbranch:branch2")
         self.assertEqual("", out)
 
     def test_status_with_shelves(self):
@@ -676,7 +670,7 @@ class TestStatus(TestCaseWithTransport):
 
         self.build_tree(["world.txt"])
         result = self.run_bzr("status -r 0")[0]
-        self.assertContainsRe(result, "added:\n  hello.txt\n" "unknown:\n  world.txt\n")
+        self.assertContainsRe(result, "added:\n  hello.txt\nunknown:\n  world.txt\n")
         result2 = self.run_bzr("status -r 0..")[0]
         self.assertEqual(result2, result)
 
@@ -697,7 +691,7 @@ class TestStatus(TestCaseWithTransport):
 
         self.build_tree(["world.txt"])
         result = self.run_bzr("status -S -r 0")[0]
-        self.assertContainsRe(result, "[+]N  hello.txt\n" "[?]   world.txt\n")
+        self.assertContainsRe(result, "[+]N  hello.txt\n[?]   world.txt\n")
         result2 = self.run_bzr("status -S -r 0..")[0]
         self.assertEqual(result2, result)
 
@@ -746,7 +740,7 @@ class TestStatus(TestCaseWithTransport):
         self.assertEqual(result2, result)
 
     def assertStatusContains(self, pattern, short=False):
-        """Run status, and assert it contains the given pattern"""
+        """Run status, and assert it contains the given pattern."""
         if short:
             result = self.run_bzr("status --short")[0]
         else:
@@ -763,7 +757,7 @@ class TestStatus(TestCaseWithTransport):
         self.assertStatusContains("kind changed:\n  file \\(file => directory\\)")
         tree.rename_one("file", "directory")
         self.assertStatusContains(
-            "renamed:\n  file => directory/\n" "modified:\n  directory/\n"
+            "renamed:\n  file => directory/\nmodified:\n  directory/\n"
         )
         rmdir("directory")
         self.assertStatusContains("removed:\n  file\n")
@@ -782,7 +776,7 @@ class TestStatus(TestCaseWithTransport):
         self.assertStatusContains("RD  file => directory", short=True)
 
     def test_status_illegal_revision_specifiers(self):
-        out, err = self.run_bzr("status -r 1..23..123", retcode=3)
+        _out, err = self.run_bzr("status -r 1..23..123", retcode=3)
         self.assertContainsRe(err, "one or two revision specifiers")
 
     def test_status_no_pending(self):
@@ -796,7 +790,7 @@ class TestStatus(TestCaseWithTransport):
         b_tree.commit("b")
 
         self.run_bzr("merge ../b", working_dir="a")
-        out, err = self.run_bzr("status --no-pending", working_dir="a")
+        out, _err = self.run_bzr("status --no-pending", working_dir="a")
         self.assertEqual(out, "added:\n  b\n")
 
     def test_pending_specific_files(self):
@@ -804,15 +798,15 @@ class TestStatus(TestCaseWithTransport):
         tree = self.make_branch_and_tree("tree")
         self.build_tree_contents([("tree/a", b"content of a\n")])
         tree.add("a")
-        r1_id = tree.commit("one")
+        tree.commit("one")
         alt = tree.controldir.sprout("alt").open_workingtree()
         self.build_tree_contents([("alt/a", b"content of a\nfrom alt\n")])
-        alt_id = alt.commit("alt")
+        alt.commit("alt")
         tree.merge_from_branch(alt.branch)
         output = self.make_utf8_encoded_stringio()
         show_tree_status(tree, to_file=output)
         self.assertContainsRe(output.getvalue(), b"pending merge")
-        out, err = self.run_bzr("status tree/a")
+        out, _err = self.run_bzr("status tree/a")
         self.assertNotContainsRe(out, "pending merge")
 
 
@@ -825,16 +819,17 @@ class TestStatusEncodings(TestCaseWithTransport):
             self.build_tree_contents([(filename, b"contents of hello")])
         except UnicodeEncodeError:
             raise TestSkipped(
-                "can't build unicode working tree in "
-                "filesystem encoding %s" % sys.getfilesystemencoding()
+                "can't build unicode working tree in filesystem encoding {}".format(
+                    sys.getfilesystemencoding()
+                )
             )
         working_tree.add(filename)
         return working_tree
 
     def test_stdout_ascii(self):
         self.overrideAttr(osutils, "_cached_user_encoding", "ascii")
-        working_tree = self.make_uncommitted_tree()
-        stdout, stderr = self.run_bzr("status")
+        self.make_uncommitted_tree()
+        stdout, _stderr = self.run_bzr("status")
 
         self.assertEqual(
             stdout,
@@ -846,8 +841,8 @@ added:
 
     def test_stdout_latin1(self):
         self.overrideAttr(osutils, "_cached_user_encoding", "latin-1")
-        working_tree = self.make_uncommitted_tree()
-        stdout, stderr = self.run_bzr("status")
+        self.make_uncommitted_tree()
+        stdout, _stderr = self.run_bzr("status")
 
         expected = """\
 added:
